@@ -26,6 +26,7 @@ from ansi2html import Ansi2HTMLConverter
 from dateutil import parser
 from docker.models.containers import Container
 from six import BytesIO
+from zuper_commons.fs import write_ustring_to_utf8_file
 from zuper_commons.text import box
 from zuper_commons.types import ZException
 
@@ -414,8 +415,8 @@ def setup_logging(wd):
         try:
             conv = Ansi2HTMLConverter()
             html = conv.convert(data)
-            with open(fn, "w") as f:
-                f.write(html)
+            write_ustring_to_utf8_file(html, fn)
+
         except:
             pass
         # os.remove(log)
@@ -593,7 +594,6 @@ def get_cr(
     cd: Optional[ChallengeDescription],
     heartbeat: Optional[Callable] = None,
 ) -> Tuple[ChallengeResults, List]:
-
     # noinspection PyBroadException
     try:
 
@@ -635,16 +635,19 @@ def get_cr(
         #     solution_container = f"{registry}/{organization}/{repository}:{tag}"
         elogger.info(f"solution_container = {solution_container}")
 
-        wd = os.path.join(
+        wd0 = os.path.join(
             tmpdir,
             challenge_name,
             f"submission{submission_id}",
             f"{challenge_step_name}-{evaluator_name}-job{job_id}",
         )
+        wd = wd0 + "-a-wd"
+        fd = wd0 + "-a-fifos"
 
         if not os.path.exists(wd):
             os.makedirs(wd)
-
+        if not os.path.exists(fd):
+            os.makedirs(fd)
         own_logs_dir = os.path.join(wd, "logs", "challenges-runner")
 
         aws_config = res["aws_config"]
@@ -671,6 +674,7 @@ def get_cr(
 
                 cr = run_single(
                     wd=wd,
+                    fd=fd,
                     aws_config=aws_config,
                     steps2artefacts=steps2artefacts,
                     challenge_parameters=challenge_parameters_,
@@ -726,7 +730,7 @@ def get_cr(
         if wd:
             if delete:
                 msg = f"I am deleting temporary dir {wd}"
-                elogger.info(msg)
+                elogger.info(msg, contents=list_all_files(wd))
                 if os.path.exists(wd):
                     shutil.rmtree(wd)
             else:
@@ -745,6 +749,7 @@ class IPFSException(Exception):
 def run_single(
     *,
     wd: str,
+    fd: str,
     aws_config,
     steps2artefacts,
     challenge_parameters: EvaluationParameters,
@@ -764,6 +769,7 @@ def run_single(
     """
 
     :param wd:
+    :param fd: Directory for fifos
     :param aws_config:
     :param steps2artefacts:
     :param challenge_parameters:
@@ -783,10 +789,7 @@ def run_single(
     :return:
     """
     prepare_dir(wd, aws_config, steps2artefacts, use_ipfs=use_ipfs)
-    fd = os.path.join(wd, "fifos")
-    if os.path.exists(fd):
-        shutil.rmtree(fd)
-    os.makedirs(fd)
+
     tomonitor: List[ContainerName] = []
     for service_name, service_def in challenge_parameters.services.items():
         if service_def.image == ChallengesConstants.SUBMISSION_CONTAINER_TAG:
@@ -803,10 +806,15 @@ def run_single(
     add_extra_environment[ENV_CHALLENGE_STEP_NAME] = challenge_step_name
     # add_extra_environment["submission_id"] = submission_id
     add_extra_environment[ChallengesConstants.SUBMISSION_CONTAINER_TAG] = solution_container
+    #
+    # fd = os.path.join(wd, "fifos")
+    # if os.path.exists(fd):
+    #     shutil.rmtree(fd)
+    # os.makedirs(fd)
 
     config = get_config(
-        wd=".",
-        fd="./fifos",
+        wd=wd,
+        fd=fd,
         server_host=server_host,
         challenge_parameters_=challenge_parameters,
         solution_container=solution_container,
@@ -824,18 +832,15 @@ def run_single(
     dcfn = os.path.join(wd, "docker-compose.yaml")
 
     # elogger.info('Compose file: \n%s ' % compose)
-    with open(dcfn_original, "w") as f:
-        f.write(config_yaml)
-    with open(dcfn, "w") as f:
-        f.write(config_yaml)
+    write_ustring_to_utf8_file(config_yaml, dcfn_original)
+    write_ustring_to_utf8_file(config_yaml, dcfn)
 
     # validate the configuration
 
     try:
         config_validated = run_docker(wd, project, ["config"], get_output=True).decode("utf-8")
-        with open(dcfn, "w") as f:
-            f.write(config_validated)
-        elogger.info(config=config_validated)
+        write_ustring_to_utf8_file(config_validated, dcfn)
+        elogger.info(config_orig=config_yaml, config_validated=config_validated)
         valid_config = True
         valid_config_error = None
     except DockerComposeFail:
@@ -981,6 +986,7 @@ def run_one(
             # '--remove-orphans',
             # '--abort-on-container-exit'
         ]
+        elogger.info("now running", wd=wd, cwd=os.getcwd(), wd_files=list_all_files(wd))
         run_docker(wd, project, cmd)
 
         service2id = {}
@@ -1056,6 +1062,9 @@ def run_one(
                         try:
                             cr = read_challenge_results(wd)
                         except NoResultsFound:
+                            msg2 = f"No results found! Something very wrong. \n{traceback.format_exc()}"
+                            elogger.error(msg2)
+                            msg += "\n\n" + msg2
                             status = ChallengesConstants.STATUS_JOB_ERROR
                             cr = ChallengeResults(status, msg, scores={})
                         return cr
@@ -1152,7 +1161,7 @@ def prepare_dir(wd, aws_config, steps2artefacts, use_ipfs: bool):
 
 def get_config(
     wd: str,
-    fd,
+    fd: str,
     challenge_parameters_,
     solution_container: str,
     add_extra_environment: Dict[str, str],
@@ -1332,12 +1341,10 @@ def write_logs(wd, project, services):
                     if not os.path.exists(logdir_service):
                         os.makedirs(logdir_service)
                     fn = os.path.join(logdir_service, "%s.log" % fname)
-                    with open(fn, "w") as f:
-                        f.write(logs)
+                    write_ustring_to_utf8_file(logs, fn)
 
                     fn = os.path.join(logdir_service, "%s.html" % fname)
-                    with open(fn, "w") as f:
-                        f.write(html)
+                    write_ustring_to_utf8_file(html, fn)
         except:
             elogger.error(traceback.format_exc())
 
@@ -1379,11 +1386,10 @@ class Tee:
 
 
 def run_docker(cwd: str, project: str, cmd0: List[str], get_output: bool = False) -> bytes:
-
     """ raises DockerComposeFail """
     cmd0 = ["docker-compose", "-p", project] + cmd0
     # elogger.info('Running:\n\t%s' % " ".join(cmd0) + '\n\n in %s' % cwd)
-    elogger.debug(command=" ".join(cmd0))
+    elogger.debug(cwd=cwd, command=" ".join(cmd0))
 
     d = tempfile.mkdtemp()
 
@@ -1465,8 +1471,7 @@ def download_artefacts(aws_config, steps2artefacts, wd, use_ipfs: bool):
     for step_name, artefacts in steps2artefacts.items():
         step_dir = os.path.join(wd, step_name)
         os.makedirs(step_dir)
-        with open(os.path.join(step_dir, "touch"), "w") as f:
-            f.write("touch")
+        write_ustring_to_utf8_file("touch", os.path.join(step_dir, "touch"))
 
         for rpath, data in artefacts.items():
             # elogger.debug(data)
@@ -1734,8 +1739,8 @@ def create_index_files(wd, job_id):
         print(root, dirnames, filenames)
         index = os.path.join(root, "index.html")
         if not os.path.exists(index):
-            with open(index, "w") as f:
-                f.write(create_index(root, dirnames, filenames, job_id))
+            d = create_index(root, dirnames, filenames, job_id)
+            write_ustring_to_utf8_file(d, index)
 
 
 def create_index(root, dirnames, filenames, job_id):
