@@ -47,9 +47,10 @@ def runner_local_main():
 
 
 def runner_local_main_(args: List[str] = None, token: str = None):
-    from duckietown_challenges.col_logging import setup_logging_color
+    if args is None:
+        from duckietown_challenges.col_logging import setup_logging_color
 
-    setup_logging_color()
+        setup_logging_color()
     prog = "dts challenges evaluate"
     parser = argparse.ArgumentParser(prog=prog, usage=usage)
 
@@ -196,9 +197,15 @@ For example, you could try:
                 shutil.rmtree(wd_final)
 
         wd = wd_final + ".tmp"
+        fd = wd_final + ".fifos"
 
+        if os.path.exists(fd):
+            shutil.rmtree(fd)
         if os.path.exists(wd):
             shutil.rmtree(wd)
+
+        if not os.path.exists(fd):
+            os.makedirs(fd)
         logger.info(f"Using working dir {wd}")
         params_tmp = os.path.join(wd, "parameters.json")
         if not os.path.exists(wd):
@@ -239,6 +246,7 @@ For example, you could try:
             require_scores = set()
         cr = run_single(
             wd=wd,
+            fd=fd,
             aws_config=aws_config,
             steps2artefacts=steps2artefacts,
             challenge_parameters=evaluation_parameters,
