@@ -1,6 +1,8 @@
 # coding=utf-8
-import os
 import subprocess
+
+from duckietown_challenges import get_important_env_build_args
+
 from . import logger
 
 
@@ -10,19 +12,19 @@ def build_image(client, path: str, tag: str, dockerfile: str, no_build: bool, no
         if no_cache:
             cmd.append("--no-cache")
         with open(dockerfile) as _:
-            contents = _.read()
-        vnames = ["AIDO_REGISTRY", "PIP_INDEX_URL"]
-        for vname in vnames:
-            if vname in contents:
-                value = os.environ.get(vname)
-                cmd.extend(["--build-arg", f"{vname}={value}"])
+            df_contents = _.read()
+
+        cmd.extend(get_important_env_build_args(df_contents))
+
         cmd.append(path)
 
         logger.info("running command", cmd=cmd)
         try:
             subprocess.check_call(cmd)
         except subprocess.CalledProcessError as e:
-            logger.error(f"Cannot run command", cmd=cmd, stderr=e.stderr)
+            logger.error(
+                f"Cannot run command", cmd=cmd, retcode=e.returncode, stdout=e.stdout, stderr=e.stderr
+            )
             raise
 
     image = client.images.get(tag)
